@@ -6,8 +6,7 @@
 #include "prio.h"
 
 int getprio(__attribute__((unused)) struct path *pp,
-	    __attribute__((unused)) char *args,
-	    __attribute__((unused)) unsigned int timeout)
+	    __attribute__((unused)) char *args)
 {
 	struct timeval tv;
 
