@@ -1,5 +1,5 @@
-#ifndef _DMEVENTS_H
-#define _DMEVENTS_H
+#ifndef DMEVENTS_H_INCLUDED
+#define DMEVENTS_H_INCLUDED
 
 #include "structs_vec.h"
 
@@ -10,4 +10,4 @@ int watch_dmevents(char *name);
 void unwatch_all_dmevents(void);
 void *wait_dmevents (void *unused);
 
-#endif /* _DMEVENTS_H */
+#endif /* DMEVENTS_H_INCLUDED */
